@@ -162,6 +162,8 @@ class Exploit < Msf::Module
   #
   ###
   class Remote < Exploit
+    require 'msf/core/exploit/auto_target'
+    include Msf::Exploit::AutoTarget
 
     #
     # Initializes the socket array.
@@ -285,9 +287,22 @@ class Exploit < Msf::Module
     # to the information hash.
     super(info)
 
+    # Skip this whole routine if there are no targets
+    unless info['Targets'].nil?
+      # Add an Automatic Target to the Exploit if it doesn't have one
+      unless has_auto_target?(info['Targets'])
+        # Don't add the automatic target unless there's already more than one target to pick from
+        if info['Targets'].count > 1
+          auto = ["Automatic", { 'AutoGenerated' => true}]
+          info['Targets'].unshift(auto)
+        end
+      end
+    end
+
+
     self.targets = Rex::Transformer.transform(info['Targets'], Array,
         [ Target ], 'Targets')
-    self.default_target = info['DefaultTarget']
+    self.default_target = info['DefaultTarget'] || 0
     self.payload_info = info['Payload'] || {}
     self.successful = false
     self.session_count = 0
@@ -321,6 +336,14 @@ class Exploit < Msf::Module
       ], Msf::Exploit)
   end
 
+  def has_auto_target?(targets=[])
+    target_names = targets.collect { |target| target.first}
+    target_names.each do |target|
+      return true if target =~ /Automatic/
+    end
+    return false
+  end
+
   ##
   #
   # Core exploit interface
@@ -665,8 +688,21 @@ class Exploit < Msf::Module
   # default target, that one will be automatically used.
   #
   def target
-    target_idx = target_index
+    if self.respond_to?(:auto_targeted_index)
+      if auto_target?
+        auto_idx = auto_targeted_index
+        if auto_idx.present?
+          datastore['TARGET'] = auto_idx
+        else
+          # If our inserted Automatic Target was selected but we failed to
+          # find a suitable target, we just grab the original first target.
+          datastore['TARGET'] = 1
+        end
+      end
 
+    end
+
+    target_idx = target_index
     return (target_idx) ? targets[target_idx.to_i] : nil
   end
 
@@ -676,9 +712,10 @@ class Exploit < Msf::Module
   def target_index
     target_idx = datastore['TARGET']
 
+    default_idx = default_target || 0
     # Use the default target if one was not supplied.
-    if (target_idx == nil and default_target and default_target >= 0)
-      target_idx = default_target
+    if (target_idx == nil and default_idx and default_idx >= 0)
+      target_idx = default_idx
     end
     return (target_idx) ? target_idx.to_i : nil
   end
